@@ -13,7 +13,8 @@ from requests_oauthlib import OAuth1, OAuth1Session
 
 from fitbit.exceptions import (BadResponse, DeleteError, HTTPBadRequest,
                                HTTPUnauthorized, HTTPForbidden,
-                               HTTPServerError, HTTPConflict, HTTPNotFound)
+                               HTTPServerError, HTTPConflict, HTTPNotFound,
+                               HTTPTooManyRequests)
 from fitbit.utils import curry
 
 
@@ -33,7 +34,7 @@ class FitbitOauthClient(object):
         Create a FitbitOauthClient object. Specify the first 5 parameters if
         you have them to access user data. Specify just the first 2 parameters
         to access anonymous data and start the set up for user authorization.
-        
+
         Set callback_uri to a URL and when the user has granted us access at
         the fitbit site, fitbit will redirect them to the URL you passed.  This
         is how we get back the magic verifier string from fitbit if we're a web
@@ -83,6 +84,11 @@ class FitbitOauthClient(object):
             raise HTTPNotFound(response)
         elif response.status_code == 409:
             raise HTTPConflict(response)
+        elif response.status_code == 429:
+            exc = HTTPTooManyRequests(response)
+            exc.retry_after_secs = int(response.headers['Retry-After'])
+            raise exc
+
         elif response.status_code >= 500:
             raise HTTPServerError(response)
         elif response.status_code >= 400:
@@ -101,14 +107,15 @@ class FitbitOauthClient(object):
         self.resource_owner_secret = token.get('oauth_token_secret')
         return token
 
-    def authorize_token_url(self):
+    def authorize_token_url(self, **kwargs):
         """Step 2: Return the URL the user needs to go to in order to grant us
         authorization to look at their data.  Then redirect the user to that
         URL, open their browser to it, or tell them to copy the URL into their
-        browser.
+        browser.  Allow the client to request the mobile display by passing
+        the display='touch' argument.
         """
-        
-        return self.oauth.authorization_url(self.authorization_url)
+
+        return self.oauth.authorization_url(self.authorization_url, **kwargs)
 
     def fetch_access_token(self, verifier, token=None):
         """Step 3: Given the verifier from fitbit, and optionally a token from
@@ -119,7 +126,7 @@ class FitbitOauthClient(object):
         if token:
             self.resource_owner_key = token.get('oauth_token')
             self.resource_owner_secret = token.get('oauth_token_secret')
-            
+
         self.oauth = OAuth1Session(
             self.client_key,
             client_secret=self.client_secret,
@@ -145,7 +152,7 @@ class Fitbit(object):
     _resource_list = [
         'body',
         'activities',
-        'foods',
+        'foods/log',
         'water',
         'sleep',
         'heart',
@@ -167,7 +174,8 @@ class Fitbit(object):
         # creating and deleting records once, and use curry to make individual
         # Methods for each
         for resource in self._resource_list:
-            setattr(self, resource, curry(self._COLLECTION_RESOURCE, resource))
+            setattr(self, resource.replace('/', '_'),
+                    curry(self._COLLECTION_RESOURCE, resource))
 
             if resource not in ['body', 'glucose']:
                 # Body and Glucose entries are not currently able to be deleted
@@ -251,7 +259,7 @@ class Fitbit(object):
 
             body(date=None, user_id=None, data=None)
             activities(date=None, user_id=None, data=None)
-            foods(date=None, user_id=None, data=None)
+            foods_log(date=None, user_id=None, data=None)
             water(date=None, user_id=None, data=None)
             sleep(date=None, user_id=None, data=None)
             heart(date=None, user_id=None, data=None)
@@ -611,7 +619,7 @@ class Fitbit(object):
             'duration': duration,
             'date': start_time.strftime("%Y-%m-%d"),
         }
-        url = "%s/%s/user/-/sleep" % (
+        url = "%s/%s/user/-/sleep.json" % (
             self.API_ENDPOINT,
             self.API_VERSION,
         )
